.. _quick-openshift:

Installing on OpenShift
=======================

.. note::

   This guide is looking for contributors expereinced with OpenShift, see
   <https://github.com/WeblateOrg/weblate/issues/2889>.

Weblate supports OpenShift, the needed integration files are in main repository
in the :file:`openshift3` directory.
